::: nyckel.NyckelId

::: nyckel.LabelName

::: nyckel.ImageSampleData

::: nyckel.TextSampleData

::: nyckel.TabularSampleData

::: nyckel.TabularFieldKey

::: nyckel.TabularFieldValue

::: nyckel.ClassificationLabel

::: nyckel.ClassificationPrediction

::: nyckel.ClassificationAnnotation

::: nyckel.TagsAnnotation

::: nyckel.TagsPrediction
